.. image:: https://github.com/multiscale/muscle3/raw/master/docs/source/muscle3_logo_readme.png
    :alt: MUSCLE 3

.. image:: https://readthedocs.org/projects/muscle3/badge/?version=master
    :target: https://muscle3.readthedocs.io/en/develop/?badge=master
    :alt: Documentation Build Status

.. image:: https://api.travis-ci.org/multiscale/muscle3.svg?branch=master
    :target: https://travis-ci.org/multiscale/muscle3
    :alt: Build Status

.. image:: https://api.codacy.com/project/badge/Coverage/ea0c833cf1ce4e13840c6498dfe27ff8
    :target: https://www.codacy.com/app/LourensVeen/muscle3
    :alt: Code Coverage

.. image:: https://api.codacy.com/project/badge/Grade/ea0c833cf1ce4e13840c6498dfe27ff8
    :target: https://www.codacy.com/app/LourensVeen/muscle3
    :alt: Codacy Grade

.. image:: https://requires.io/github/multiscale/muscle3/requirements.svg?branch=master
     :target: https://requires.io/github/multiscale/muscle3/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://zenodo.org/badge/122876985.svg
   :target: https://zenodo.org/badge/latestdoi/122876985

|

MUSCLE 3 is the third incarnation of the MUSCLE Multiscale Coupling Library and
Environment. It is developed by the e-MUSC project of the University of
Amsterdam and the Netherlands eScience Center.

A first version of MUSCLE 3 is now available! This is Python-only; support for
C++, C and Fortran is under active development. Browse to
`the MUSCLE 3 documentation`_ to get started.


Legal
=====

MUSCLE 3 is Copyright 2018 University of Amsterdam and Netherlands eScience
Center. It is licensed under the Apache License 2.0.


Contributing
============

We welcome contributions to MUSCLE 3! For small additions or fixes, please
submit a pull request, and we'll review your changes and apply them. If you
want to add larger features, please make an issue and describe what you want to
do, so that we can coordinate and avoid double work. For more details, see the
`documentation on contributing`_.

The MUSCLE 3 community fosters a welcoming atmosphere, and participation is open
to everyone. In order to ensure that it stays that way, we have a
`code of conduct`_, and we will enforce it if necessary. Please treat your
fellow human beings with respect.


Tooling
=======

Tests can be run using::

  python setup.py test

The documentation can be built using::

  python setup.py build_sphinx


.. _`the MUSCLE 3 documentation`: https://muscle3.readthedocs.io
.. _`documentation on contributing`: http://muscle3.readthedocs.io/en/latest/contributing.html
.. _`code of conduct`: https://github.com/multiscale/muscle3/blob/develop/CODE_OF_CONDUCT.md
